==> jc-1.4.0.tar.gz: soot/util/Debug.c <==
// public class soot.util.Debug

// class file dependencies
// @dep_class c4d3cc2bda03a338 java_io_ByteArrayOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 75f014535cd80b2e java_io_PrintStream
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 32eb1b353b35bdb4 soot_util_Debug

// header file dependencies
// @dep_header java_io_ByteArrayOutputStream
// @dep_header java_io_PrintStream
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_Throwable
// @dep_header java_lang_VMThrowable
// @dep_header soot_util_Debug

#include "jc_defs.h"

#include "java/io/ByteArrayOutputStream.h"
#include "java/io/PrintStream.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/Throwable.h"
#include "java/lang/VMThrowable.h"
#include "soot/util/Debug.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// private static java.lang.String getStackTrace()
//

static _jc_linenum _jc_soot_util_Debug$linenum_table$getStackTrace$56d1500724703e04[];

static const unsigned char _jc_soot_util_Debug$param_ptypes$getStackTrace$56d1500724703e04[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_util_Debug$method_info$getStackTrace$56d1500724703e04 = {
	.name=			"getStackTrace",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_util_Debug$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_util_Debug$param_ptypes$getStackTrace$56d1500724703e04,
	.signature_hash=	_JC_JLONG(0x56d1500724703e04),
	.access_flags=		_JC_ACC_PRIVATE|_JC_ACC_STATIC,
	.function=		&_jc_soot_util_Debug$method$getStackTrace$56d1500724703e04,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_soot_util_Debug$linenum_table$getStackTrace$56d1500724703e04
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_Debug, getStackTrace$56d1500724703e04);

_jc_java_lang_String$object *
_jc_soot_util_Debug$method$getStackTrace$56d1500724703e04(_jc_env *const env)
{
	jint i0;
	jint i1;
	struct _jc_java_lang_Throwable$object *r0;
	struct _jc_java_io_ByteArrayOutputStream$object *r1;
	_jc_byte_array *r10;
	struct _jc_java_io_PrintStream$object *r2;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_String$object *r5;
	struct _jc_java_lang_VMThrowable$object *r6;
	_jc_byte_array *r7;
	struct _jc_java_lang_String$object *r9;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(41);				// 0
	r0 = _JC_NEW(env, java_lang_Throwable);
	r5 = _JC_NULL;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r5;
	_JC_LINE_NUMBER(42);				// 1
	r1 = _JC_NEW(env, java_io_ByteArrayOutputStream);
	i0 = _JC_STATIC_FIELD(env, java_io_ByteArrayOutputStream, initial__5fbuffer__5fsize, 1);
	r7 = _JC_NEW_PRIM_ARRAY(env, byte, 1, i0);
	_JC_REF_FIELD(env, r1, java_io_ByteArrayOutputStream, buf) = r7;
	_JC_PRIM_FIELD(env, r1, java_io_ByteArrayOutputStream, count) = 0;
	_JC_LINE_NUMBER(44);				// 2
	r2 = _JC_NEW(env, java_io_PrintStream);
	_JC_INVOKE_NONVIRTUAL(env, java_io_PrintStream, _init$8cdb616ddcb92a6a, 0, r2, r1, 0);
	r4 = _JC_INVOKE_NONVIRTUAL(env, java_lang_Throwable, stackTraceString$42eec01c019ee6b0, 0, r0);
	_JC_INVOKE_NONVIRTUAL(env, java_io_PrintStream, print$21bdbb15afdbea95, 0, r2, r4);
	r9 = _JC_NEW(env, java_lang_String);
	r10 = _JC_REF_FIELD(env, r1, java_io_ByteArrayOutputStream, buf);
	i1 = _JC_PRIM_FIELD(env, r1, java_io_ByteArrayOutputStream, count);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$4ff4a7925ef7b06c, 0, r9, r10, 0, i1);
	_JC_LINE_NUMBER(46);				// 3
	return r9;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_soot_util_Debug$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_util_Debug$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_util_Debug$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_util_Debug$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_util_Debug$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_soot_util_Debug$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_util_Debug$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_Debug, _init$52f4ad9f2989aeee);

void
_jc_soot_util_Debug$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_util_Debug$object *this)
{
	struct _jc_soot_util_Debug$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(37);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_util_Debug$methods[] = {
	&_jc_soot_util_Debug$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_util_Debug$method_info$getStackTrace$56d1500724703e04
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_util_Debug$instanceof_hash_bucket_52[] = {
	&_jc_soot_util_Debug$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_util_Debug$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_util_Debug$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[52]=	_jc_soot_util_Debug$instanceof_hash_bucket_52,
	[113]=	_jc_soot_util_Debug$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_util_Debug$class_depends[] = {
	{ "java/io/ByteArrayOutputStream",	_JC_JLONG(0xc4d3cc2bda03a338) },
	{ "java/io/OutputStream",	_JC_JLONG(0x4026d3144d6654d8) },
	{ "java/io/PrintStream",	_JC_JLONG(0x75f014535cd80b2e) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_util_Debug$vtype _jc_soot_util_Debug$type = {
    .type= {
	.name=			"soot/util/Debug",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x32eb1b353b35bdb4),
		.source_file=		"Debug.java",
		.instance_size=		sizeof(_jc_soot_util_Debug$refs) + sizeof(_jc_soot_util_Debug$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_util_Debug$methods) / sizeof(*_jc_soot_util_Debug$methods),
		.methods=		_jc_soot_util_Debug$methods,
		.instanceof_hash_table=	_jc_soot_util_Debug$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_util_Debug$class_depends) / sizeof(*_jc_soot_util_Debug$class_depends),
		.class_depends=		_jc_soot_util_Debug$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_util_Debug= {
	},
    }
};

==> jc-1.4.5.tar.gz: soot/util/Debug.c <==
// public class soot.util.Debug

// class file dependencies
// @dep_class c4d3cc2bda03a338 java_io_ByteArrayOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 99a46305ebacacb5 java_io_PrintStream
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 32eb1b353b35bdb4 soot_util_Debug

// header file dependencies
// @dep_header java_io_ByteArrayOutputStream
// @dep_header java_io_PrintStream
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_Throwable
// @dep_header java_lang_VMThrowable
// @dep_header soot_util_Debug

#include "jc_defs.h"

#include "java/io/ByteArrayOutputStream.h"
#include "java/io/PrintStream.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/Throwable.h"
#include "java/lang/VMThrowable.h"
#include "soot/util/Debug.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// private static java.lang.String getStackTrace()
//

static _jc_linenum _jc_soot_util_Debug$linenum_table$getStackTrace$56d1500724703e04[];

static const unsigned char _jc_soot_util_Debug$param_ptypes$getStackTrace$56d1500724703e04[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_util_Debug$method_info$getStackTrace$56d1500724703e04 = {
	.name=			"getStackTrace",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_util_Debug$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_util_Debug$param_ptypes$getStackTrace$56d1500724703e04,
	.signature_hash=	_JC_JLONG(0x56d1500724703e04),
	.access_flags=		_JC_ACC_PRIVATE|_JC_ACC_STATIC,
	.function=		&_jc_soot_util_Debug$method$getStackTrace$56d1500724703e04,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_soot_util_Debug$linenum_table$getStackTrace$56d1500724703e04
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_Debug, getStackTrace$56d1500724703e04);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_util_Debug$method$getStackTrace$56d1500724703e04(_jc_env *const env)
{
	jint i0;
	jint i1;
	struct _jc_java_lang_Throwable$object *r0;
	struct _jc_java_io_ByteArrayOutputStream$object *r1;
	_jc_byte_array *r10;
	struct _jc_java_io_PrintStream$object *r2;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_String$object *r5;
	struct _jc_java_lang_VMThrowable$object *r6;
	_jc_byte_array *r7;
	struct _jc_java_lang_String$object *r9;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(41);				// 0
	r0 = _JC_NEW(env, java_lang_Throwable);
	r5 = _JC_NULL;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r5;
	_JC_LINE_NUMBER(42);				// 1
	r1 = _JC_NEW(env, java_io_ByteArrayOutputStream);
	i0 = _JC_STATIC_FIELD(env, java_io_ByteArrayOutputStream, initial__5fbuffer__5fsize, 1);
	r7 = _JC_NEW_PRIM_ARRAY(env, byte, 1, i0);
	_JC_REF_FIELD(env, r1, java_io_ByteArrayOutputStream, buf) = r7;
	_JC_PRIM_FIELD(env, r1, java_io_ByteArrayOutputStream, count) = 0;
	_JC_LINE_NUMBER(44);				// 2
	r2 = _JC_NEW(env, java_io_PrintStream);
	_JC_INVOKE_NONVIRTUAL(env, java_io_PrintStream, _init$8cdb616ddcb92a6a, 0, r2, r1, 0);
	r4 = _JC_INVOKE_NONVIRTUAL(env, java_lang_Throwable, stackTraceString$42eec01c019ee6b0, 0, r0);
	_JC_INVOKE_NONVIRTUAL(env, java_io_PrintStream, print$21bdbb15afdbea95, 0, r2, r4);
	r9 = _JC_NEW(env, java_lang_String);
	r10 = _JC_REF_FIELD(env, r1, java_io_ByteArrayOutputStream, buf);
	i1 = _JC_PRIM_FIELD(env, r1, java_io_ByteArrayOutputStream, count);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$4ff4a7925ef7b06c, 0, r9, r10, 0, i1);
	_JC_LINE_NUMBER(46);				// 3
	return r9;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_soot_util_Debug$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_util_Debug$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_util_Debug$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_util_Debug$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_util_Debug$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_soot_util_Debug$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_util_Debug$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_Debug, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_util_Debug$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_util_Debug$object *this)
{
	struct _jc_soot_util_Debug$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(37);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_util_Debug$methods[] = {
	&_jc_soot_util_Debug$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_util_Debug$method_info$getStackTrace$56d1500724703e04
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_util_Debug$instanceof_hash_bucket_52[] = {
	&_jc_soot_util_Debug$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_util_Debug$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_util_Debug$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[52]=	_jc_soot_util_Debug$instanceof_hash_bucket_52,
	[101]=	_jc_soot_util_Debug$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_util_Debug$class_depends[] = {
	{ "java/io/ByteArrayOutputStream",	_JC_JLONG(0xc4d3cc2bda03a338) },
	{ "java/io/OutputStream",	_JC_JLONG(0x4026d3144d6654d8) },
	{ "java/io/PrintStream",	_JC_JLONG(0x99a46305ebacacb5) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_util_Debug$vtype _jc_soot_util_Debug$type = {
    .type= {
	.name=			"soot/util/Debug",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x32eb1b353b35bdb4),
		.source_file=		"Debug.java",
		.instance_size=		sizeof(_jc_soot_util_Debug$refs) + sizeof(_jc_soot_util_Debug$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_util_Debug$methods) / sizeof(*_jc_soot_util_Debug$methods),
		.methods=		_jc_soot_util_Debug$methods,
		.instanceof_hash_table=	_jc_soot_util_Debug$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_util_Debug$class_depends) / sizeof(*_jc_soot_util_Debug$class_depends),
		.class_depends=		_jc_soot_util_Debug$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_util_Debug= {
	},
    }
};
